@@ -206,6 +206,12 @@ class Biglist(Sequence):
             z = deserializer.deserialize(path.read_bytes())
             return [cls.post_deserialize(v) for v in z]
 
+    @classmethod
+    @contextmanager
+    def _lockfile(cls, file: Upath):
+        with file.lock():
+            yield
+
     @classmethod
     def pre_serialize(cls, x):
         '''When the data element is an instance of a custom type,
@@ -479,7 +485,7 @@ class Biglist(Sequence):
             self._flush()
 
     def _append_data_files_info(self, filename: str, length: int):
-        with self._data_info_file.lock():
+        with self._lockfile(self._data_info_file.with_suffix('.json.lock')):
             z = self.get_data_files()
             z.append((filename, length))
             self._data_info_file.write_json(z, overwrite=True)
@@ -593,7 +599,8 @@ class Biglist(Sequence):
         file_idx = None
         file_name = None
         while True:
-            with self._fileiter_info_file(task_id).lock() as ff:
+            ff = self._fileiter_info_file(task_id)
+            with self._lockfile(ff.with_suffix('.json.lock')):
                 iter_info = ff.read_json()
                 if file_idx is not None:
                     z = iter_info[file_idx]
